<xsl:stylesheet version="1.0" 
	xmlns:sc="http://www.utc.fr/ics/scenari/v3/core" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:sp="http://www.utc.fr/ics/scenari/v3/primitive" 
	xmlns:op="utc.fr:ics/opale3"
	exclude-result-prefixes="sc sp op">
	<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="yes" omit-xml-declaration="yes"/>
	<xsl:param name="vDialog"/>
	<xsl:param name="vAgent"/>
	
	<xsl:template match="op:vidInd">
		<videoIndex>
			<!-- NOTES : 
				- le player flash oblige que le FLV soit dans une arborescence frere ou fille du SWF => copie du FLV dans le rep RES...
			-->
			<xsl:value-of select="resultatAgent('//', 'res:src=bs:VideoIndexee.swf')"/>
			<xsl:apply-templates select="op:vidIndM"/><!-- metas -->
			<xsl:apply-templates select="op:vidIndM/sp:flv"/><!-- flv -->
			<index>
				<xsl:apply-templates select="sp:seg | sp:part"/>
				<!-- 
					<section id="i1" titre="1 Introduction" start="0" end="10">
					<segment id="i2" titre="1.1 Présentation" start="0" end="5"/>
					<segment id="i3" titre="1.2 Thématique" start="5" end="10"/>
					<complements>
					<complement titre="Plus d'informations à propos de la démarche" url="http://www.google.fr"/>
					<complement titre="Un second complément à l'introduction kjhjk jkhjkhkj lkj kjlk ghghg jhkjhkjh" url="http://www.yahoo.fr"/>
					</complements>
					</section>
				-->
			</index>
		</videoIndex>
	</xsl:template>
	
	<!-- Création de l'index -->
	<xsl:template match="sp:part">
		<section id="{generate-id()}" titre="{op:vidPart/op:sTitle/sc:fullTitle}">
			<xsl:apply-templates select="op:vidPart/sp:seg | op:vidPart/sp:part"/>
		</section>
	</xsl:template>
	
	<xsl:template match="sp:seg">
		<xsl:variable name="vStart" select="op:vidSeg/op:vidSegM/sp:tStart"/><!-- TODO: gérer la cohérence si le player ne gère pas les discontinuités -->
		<xsl:variable name="vEnd" select="op:vidSeg/op:vidSegM/sp:tEnd"/><!-- TODO: gérer la cohérence si le player ne gère pas les discontinuités -->
		<segment id="{generate-id()}" titre="{op:vidSeg/op:vidSegM/sp:title}" start="{$vStart}" end="{$vEnd}">
			<xsl:apply-templates select="op:vidSeg/op:vidSegM/sp:cplts"/>
		</segment>
	</xsl:template>
	
	<xsl:template match="sp:cplts">
		<complements>
			<xsl:apply-templates/>
		</complements>
	</xsl:template>
	<xsl:template match="sp:link">
		<complement titre="{sp:name/text()}" url="{sp:url/text()}"  ico="../tplRes/videoInd/res/html.gif" />
	</xsl:template>
	<xsl:template match="sp:doc">
		<xsl:variable name="vUrl" select="getUrl(gotoSubModel(), 'url')"/>
		<xsl:variable name="vDocTitle" select="si(string-length(getFullTitleText(gotoSubModel(), 'url'))&gt;0, getFullTitleText(gotoSubModel(), 'url'), extractFileNameFromPath($vUrl))"/>
		<complement titre="{$vDocTitle}" url="{getUrl(gotoSubModel(), 'url')}">
			<xsl:choose>
				<xsl:when test="substring($vUrl, string-length($vUrl) - 2, 3)='xls'"><xsl:attribute name="ico">../tplRes/videoInd/res/xls.jpg</xsl:attribute></xsl:when>
				<xsl:when test="substring($vUrl, string-length($vUrl) - 2, 3)='doc'"><xsl:attribute name="ico">../tplRes/videoInd/res/doc.jpg</xsl:attribute></xsl:when>
				<xsl:when test="substring($vUrl, string-length($vUrl) - 2, 3)='pdf'"><xsl:attribute name="ico">../tplRes/videoInd/res/pdf.gif</xsl:attribute></xsl:when>
				<xsl:when test="substring($vUrl, string-length($vUrl) - 2, 3)='tml'"><xsl:attribute name="ico">../tplRes/videoInd/res/html.gif</xsl:attribute></xsl:when>
			</xsl:choose>
		</complement>
	</xsl:template>
	
	<!-- Metas -->
	<xsl:template match="op:vidIndM">
		<metas>
			<main>
				<titre text="{getFullTitleText(currentModel(), '')}"/>
				<logos>
					<xsl:for-each select="sp:desc/sp:logo[1]">
						<logo src="{getUrl(gotoSubModel(), 'url')}"/>
					</xsl:for-each>
				</logos>
			</main>
			<infos>
				<xsl:apply-templates select="sp:desc/sp:txt/op:vidDesc"/>
				<logos>
					<xsl:for-each select="sp:desc/sp:logo[position()&gt;1]">
						<logo src="{getUrl(gotoSubModel(), 'url')}"/>
					</xsl:for-each>
				</logos>
			</infos>
			<help>
				<text>
					<p><b>Navigation</b></p>
					<p>Le plan de gauche vous permet d&apos;accéder à des séquences de la vidéo. La séquence en cours de lecture est placée sur un fond coloré.</p>
					<p><b>Barre de contrôle</b></p>
					<p/>
					<p>- Affichage / Suppression du plan;</p>
					<p>- Lecture de la vidéo;</p>
					<p>- Mise en pause de la vidéo;</p>
					<p>- Barre de progression;</p>
					<p>- Zone de contrôle du volume;</p>
					<p>- Affichage de la vidéo à sa taille originale / Affichage de la vidéo en exploitant toute la place disponible;</p>
					<p>- Mode plein écran;</p>
					<p>- Description de la vidéo;</p>
					<p>- Bouton d&apos;aide;</p>
					<p>- Affichage ou non de la barre de contrôle;</p>
				</text>
			</help>
		</metas>
	</xsl:template>
	<xsl:template match="op:vidDesc">
		<text>
			<xsl:apply-templates/>
		</text>
	</xsl:template>
	<xsl:template match="sc:para">
		<p><xsl:apply-templates/></p>
	</xsl:template>
	<xsl:template match="sc:inlineStyle[@role='emp']">
		<b><xsl:apply-templates/></b>
	</xsl:template>
	<xsl:template match="sc:inlineStyle[@role='spec']">
		<i><xsl:apply-templates/></i>
	</xsl:template>
	
	<!-- Vidéo -->
	<xsl:template match="sp:flv">
		<!-- NOTES : 
			- les paths sont donnés par rapport au SWF
			- le player flash oblige que le FLV soit dans une arborescence frere ou fille du SWF
		-->
		<xsl:variable name="vBegin" select="//sp:seg[1]/op:vidSeg/op:vidSegM/sp:tStart"/>
		<xsl:variable name="vEnd" select="//sp:seg[count(following::sp:seg) = 0]/op:vidSeg/op:vidSegM/sp:tEnd"/>
		<xsl:variable name="vMode" select="si(not(../sp:desc/sp:menu) or ../sp:desc/sp:menu/text()='zone', 'normal', 'overlay')"/>
		<xsl:variable name="vInsertWidth" select="si(../sp:desc/sp:menu/text()='overlayBox', '300', '0')"/>
		<xsl:variable name="vInsertHeight" select="si(../sp:desc/sp:menu/text()='overlayBox', '300', '0')"/>
		
		<xsl:variable name="vIsLocal">
			<xsl:choose>
				<!-- contexte : flv locale -->
				<xsl:when test="contains(resultatAgent('/@@/contentRoot'), '_ArootFlv')">
					<xsl:text>true</xsl:text>
				</xsl:when>
				<!-- contexte : flv stream -->
				<xsl:when test="contains(resultatAgent('/@@/contentRoot'), '_ArootStream')">
					<xsl:text>false</xsl:text>
				</xsl:when>
				<!-- pas de contexte : priorité au stream -->
				<xsl:when test="sp:stream">
					<xsl:text>false</xsl:text>
				</xsl:when>
				<xsl:otherwise><!-- flv locale -->
					<xsl:text>true</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:choose>
			<xsl:when test="$vIsLocal='true'"><!-- Local -->
				<xsl:variable name="vPath" select="si(sp:loc, substring(getUrl(gotoSubModel(sp:loc), 'url'), 8, string-length(getUrl(gotoSubModel(sp:loc), 'url'))))"/>
				<video src="{$vPath}" clipBegin="{$vBegin}" clipEnd="{$vEnd}" menuMode="{$vMode}">
					<xsl:if test="$vInsertWidth!='0'"><xsl:attribute name="insertWidth"><xsl:value-of select="$vInsertWidth"/></xsl:attribute></xsl:if>
					<xsl:if test="$vInsertHeight!='0'"><xsl:attribute name="insertHeight"><xsl:value-of select="$vInsertHeight"/></xsl:attribute></xsl:if>
				</video>
			</xsl:when>
			<xsl:otherwise><!-- Stream -->
				<video src="{normalize-space(sp:stream)}" clipBegin="{$vBegin}" clipEnd="{$vEnd}" menuMode="{$vMode}">
					<xsl:if test="$vInsertWidth!='0'"><xsl:attribute name="insertWidth"><xsl:value-of select="$vInsertWidth"/></xsl:attribute></xsl:if>
					<xsl:if test="$vInsertHeight!='0'"><xsl:attribute name="insertHeight"><xsl:value-of select="$vInsertHeight"/></xsl:attribute></xsl:if>
				</video>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:template>
	
	<xsl:template match="*"/>
	
</xsl:stylesheet>
