<?xml version='1.0' encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:m="http://www.w3.org/1998/Math/MathML"
    version="1.0">
<!-- FRK -->
    <!-- ====================================================================== -->
    <!-- place un '"' avant et après l'entité à remplacer si elle est placée dans un mtext 
    (évite les erreurs lors de l'importation sous oo) -->
    <!-- ====================================================================== -->
    <xsl:template name="replaceEntity">
        <xsl:param name="newValue"/>
        <xsl:if test="./ancestor::m:mtext">
            <xsl:text>"</xsl:text>
        </xsl:if>
        <xsl:value-of select="$newValue"/>
        <xsl:if test="./ancestor::m:mtext">
            <xsl:text>"</xsl:text>
        </xsl:if>
    </xsl:template>

    <xsl:template name="insertEntity">
        <xsl:param name="content"></xsl:param>
        <xsl:text>"</xsl:text>
        <xsl:value-of select="substring($content,1,1)"/>
        <xsl:text>"</xsl:text>
        <xsl:call-template name="replaceEntities">
            <xsl:with-param name="content" select="substring($content, 2)"/>
        </xsl:call-template>
    </xsl:template>
    
    
    <!-- ====================================================================== -->
    <!-- $id: entities.xsl, 2002/22/11 Exp $
     This file is part of the XSLT MathML Library distribution.
     See ./README or http://www.raleigh.ru/MathML/mmltex for
     copyright and other information                                        -->
    <!-- ====================================================================== -->

    <xsl:template name="replaceEntities">
        <xsl:param name="content"/>
        <xsl:if test="string-length($content)>0">
            <xsl:choose>
                <xsl:when test="starts-with($content,'%')">
                    <xsl:text>"%"</xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '%')"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- ====================================================================== -->
                <!--    Unicode 3.2
                        Greek
                        Range: 0370-03FF
                        http://www.unicode.org/charts/PDF/U0370.pdf                     -->
                <!-- ====================================================================== -->
                <!--/': prime -->
                <xsl:when test="starts-with($content,'&#x02B9;')">
                    <xsl:text>'</xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02B9;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/varepsilon capital varepsilon, Greek -->
                <xsl:when test="starts-with($content,'&#x0025B;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%varepsilon '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0025B;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/GAMMA capital GAMMA, Greek -->
                <xsl:when test="starts-with($content,'&#x00393;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%GAMMA '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x00393;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/DELTA capital DELTA, Greek -->
                <xsl:when test="starts-with($content,'&#x00394;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%DELTA '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x00394;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/THETA capital THETA, Greek -->
                <xsl:when test="starts-with($content,'&#x00398;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%THETA '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x00398;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/LAMBDA capital LAMBDA, Greek -->
                <xsl:when test="starts-with($content,'&#x0039B;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%LAMBDA '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0039B;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/Xi capital Xi, Greek -->
                <xsl:when test="starts-with($content,'&#x0039E;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%XI '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0039E;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/Pi capital Pi, Greek -->
                <xsl:when test="starts-with($content,'&#x003A0;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%PI '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003A0;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/Sigma capital Sigma, Greek -->
                <xsl:when test="starts-with($content,'&#x003A3;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%SIGMA '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003A3;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/Phi capital Phi, Greek -->
                <xsl:when test="starts-with($content,'&#x003A6;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%PHI '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003A6;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/Psi capital Psi, Greek -->
                <xsl:when test="starts-with($content,'&#x003A8;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%PSI '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003A8;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/Omega capital Omega, Greek -->
                <xsl:when test="starts-with($content,'&#x003A9;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%OMEGA '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003A9;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/alpha small alpha, Greek -->
                <xsl:when test="starts-with($content,'&#x003B1;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%alpha '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003B1;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/beta small beta, Greek -->
                <xsl:when test="starts-with($content,'&#x003B2;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%beta '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003B2;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/gamma small gamma, Greek -->
                <xsl:when test="starts-with($content,'&#x003B3;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%gamma '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003B3;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/delta small delta, Greek -->
                <xsl:when test="starts-with($content,'&#x003B4;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%delta '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003B4;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/straightepsilon, small epsilon, Greek -->
                <xsl:when test="starts-with($content,'&#x003B5;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%epsilon '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003B5;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/zeta small zeta, Greek -->
                <xsl:when test="starts-with($content,'&#x003B6;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%zeta '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003B6;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/eta small eta, Greek -->
                <xsl:when test="starts-with($content,'&#x003B7;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%eta '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003B7;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/theta straight theta, small theta, Greek -->
                <xsl:when test="starts-with($content,'&#x003B8;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%theta '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003B8;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/iota small iota, Greek -->
                <xsl:when test="starts-with($content,'&#x003B9;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%iota '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003B9;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/kappa small kappa, Greek -->
                <xsl:when test="starts-with($content,'&#x003BA;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%kappa '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003BA;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/lambda small lambda, Greek -->
                <xsl:when test="starts-with($content,'&#x003BB;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%lambda '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003BB;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/mu small mu, Greek -->
                <xsl:when test="starts-with($content,'&#x003BC;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%mu '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003BC;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/mu small mu, Greek -->
                <xsl:when test="starts-with($content,'&#xB5;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%mu '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#xB5;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/nu small nu, Greek -->
                <xsl:when test="starts-with($content,'&#x003BD;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%nu '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003BD;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/xi small xi, Greek -->
                <xsl:when test="starts-with($content,'&#x003BE;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%xi '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003BE;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/pi small pi, Greek -->
                <xsl:when test="starts-with($content,'&#x003C0;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%pi '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003C0;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/rho small rho, Greek -->
                <xsl:when test="starts-with($content,'&#x003C1;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%rho '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003C1;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/varsigma -->
                <xsl:when test="starts-with($content,'&#x003C2;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%varsigma '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003C2;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/sigma small sigma, Greek -->
                <xsl:when test="starts-with($content,'&#x003C3;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%sigma '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003C3;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/tau small tau, Greek -->
                <xsl:when test="starts-with($content,'&#x003C4;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%tau '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003C4;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/upsilon small upsilon, Greek -->
                <xsl:when test="starts-with($content,'&#x003C5;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%upsilon '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003C5;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/straightphi - small phi, Greek -->
                <xsl:when test="starts-with($content,'&#x003C6;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%phi '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003C6;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/chi small chi, Greek -->
                <xsl:when test="starts-with($content,'&#x003C7;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%chi '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003C7;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/psi small psi, Greek -->
                <xsl:when test="starts-with($content,'&#x003C8;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%psi '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003C8;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/omega small omega, Greek -->
                <xsl:when test="starts-with($content,'&#x003C9;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%omega '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003C9;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/vartheta - curly or open theta -->
                <xsl:when test="starts-with($content,'&#x003D1;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%vartheta '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003D1;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/Upsilon capital Upsilon, Greek -->
                <xsl:when test="starts-with($content,'&#x003D2;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%UPSILON '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003D2;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/varphi - curly or open phi -->
                <xsl:when test="starts-with($content,'&#x003D5;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%varphi '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003D5;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/varpi -->
                <xsl:when test="starts-with($content,'&#x003D6;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%varpi '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003D6;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/varkappa -->
                <xsl:when test="starts-with($content,'&#x003F0;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%varkappa '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003F0;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/varrho -->
                <xsl:when test="starts-with($content,'&#x003F1;')">
                    <xsl:call-template name="replaceEntity">
                        <xsl:with-param name="newValue" select="'%varrho '"/>
                    </xsl:call-template>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x003F1;')"/>
                    </xsl:call-template>
                </xsl:when>

                <!-- ====================================================================== -->
                <xsl:when test="starts-with($content,'&#x0200B;')">
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0200B;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--short form of  &InvisibleComma; -->
                <xsl:when test="starts-with($content,'&#x02026;')">
                    <xsl:value-of select="' dotslow  '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02026;')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content,'&#x0B0;')">
                    <xsl:choose>
                        <xsl:when test="ancestor::m:msub">
                            <xsl:value-of select="' {o} '"/>
                            <xsl:call-template name="replaceEntities">
                                <xsl:with-param name="content" select="substring-after($content, '&#x0B0;')"/>
                            </xsl:call-template>
                        </xsl:when>
                        <xsl:otherwise>
                            <xsl:value-of select="'^{o} '"/>
                            <xsl:call-template name="replaceEntities">
                                <xsl:with-param name="content" select="substring-after($content, '&#x0B0;')"/>
                            </xsl:call-template>
                        </xsl:otherwise>
                    </xsl:choose>
                </xsl:when>
                <!--degree -->

                <!--<xsl:when test="starts-with($content,'&#x02032;')"><xsl:value-of select="substring($content,1,1)"/><xsl:call-template name="replaceEntities"><xsl:with-param name="content" select="substring($content, 2)"/></xsl:call-template></xsl:when>-->
                <!--/prime prime or minute (just copy entity)-->

                <xsl:when test="starts-with($content,'&#x02061;')">
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02061;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- ApplyFunction -->
                <xsl:when test="starts-with($content,'&#x02062;')">
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02062;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- InvisibleTimes -->
                <!-- ====================================================================== -->
                <!--    Unicode 3.2
                        Letterlike Symbols
                        Range: 2100-214F
                        http://www.unicode.org/charts/PDF/U2100.pdf                     -->
                <!-- ====================================================================== -->
                <!--/hbar - Planck's over 2pi -->
                <xsl:when test="starts-with($content,'&#x0210F;&#x0FE00;')">
                    <xsl:value-of select="' hbar '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0210F;&#x0FE00;')"
                        />
                    </xsl:call-template>
                </xsl:when>
                <!--/hslash - variant Planck's over 2pi -->
                <xsl:when test="starts-with($content,'&#x0210F;')">
                    <xsl:value-of select="' hbar '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0210F;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/Im - imaginary   -->
                <xsl:when test="starts-with($content,'&#x02111;')">
                    <xsl:value-of select="' Im '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02111;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/ell - cursive small l (just copy entity)-->
                <xsl:when test="starts-with($content,'&#x02113;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/wp - Weierstrass p (just copy entity)-->
                <xsl:when test="starts-with($content,'&#x02118;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/Re - real (just copy entity)-->
                <xsl:when test="starts-with($content,'&#x0211C;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/mho - conductance (just copy entity)-->
                <xsl:when test="starts-with($content,'&#x02127;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/aleph aleph, Hebrew -->
                <xsl:when test="starts-with($content,'&#x02135;')">
                    <xsl:value-of select="' aleph '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02135;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/beth - beth, Hebrew (just copy entity)-->
                <xsl:when test="starts-with($content,'&#x02136;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/gimel - gimel, Hebrew (just copy entity)-->
                <xsl:when test="starts-with($content,'&#x02137;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/daleth - daleth, Hebrew (just copy entity)-->
                <xsl:when test="starts-with($content,'&#x02138;')">                 
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--D for use in differentials, e.g., within integrals -->
                <xsl:when test="starts-with($content,'&#x02145;')">
                    <xsl:value-of select="'D'"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02145;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--d for use in differentials, e.g., within integrals -->
                <xsl:when test="starts-with($content,'&#x02146;')">
                    <xsl:value-of select="'d'"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02146;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--e use for the exponential base of the natural logarithms -->
                <xsl:when test="starts-with($content,'&#x02147;')">
                    <xsl:value-of select="'e'"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02147;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--i for use as a square root of -1 -->
                <xsl:when test="starts-with($content,'&#x02148;')">
                    <xsl:value-of select="'i'"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02148;')"/>
                    </xsl:call-template>
                </xsl:when>

                <!-- ====================================================================== -->
                <!--\to toward  =rightward arrow -->
                <xsl:when test="starts-with($content,'&#x02192;')">
                    <xsl:value-of select="' toward '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02192;')"/>
                    </xsl:call-template>
                </xsl:when>

                <!-- ====================================================================== -->
                <!--    Unicode 3.2
                        Mathematical Operators
                        Range: 2200-22FF
                        http://www.unicode.org/charts/PDF/U2200.pdf                         -->
                <!-- ====================================================================== -->
                <!--times -->
                <xsl:when test="starts-with($content,'&#x00D7;')">
                    <xsl:value-of select="' times '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x00D7;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/forall for all -->
                <xsl:when test="starts-with($content,'&#x02200;')">
                    <xsl:value-of select="' forall '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02200;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/complement - complement sign (just copy entity)-->
                <xsl:when test="starts-with($content,'&#x02201;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/partial partial differential -->
                <xsl:when test="starts-with($content,'&#x02202;')">
                    <xsl:value-of select="' partial '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02202;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/exists at least one exists -->
                <xsl:when test="starts-with($content,'&#x02203;')">
                    <xsl:value-of select="' exists '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02203;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/nexists - negated exists -->
                <xsl:when test="starts-with($content,'&#x02204;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/emptyset - zero, slash -->
                <xsl:when test="starts-with($content,'&#x02205;&#x0FE00;')">
                    <xsl:value-of select="' emptyset '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02205;&#x0FE00;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/varnothing - circle, slash -->
                <xsl:when test="starts-with($content,'&#x02205;')">
                    <xsl:value-of select="' emptyset '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02205;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/Delta capital Delta, Greek -->
                <xsl:when test="starts-with($content,'&#x02206;')">
                    <xsl:value-of select="'%DELTA '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02206;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/nabla del, Hamilton operator -->
                <xsl:when test="starts-with($content,'&#x02207;')">
                    <xsl:value-of select="' nabla '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02207;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/in R: set membership  -->
                <xsl:when test="starts-with($content,'&#x02208;')">
                    <xsl:value-of select="' in '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02208;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/notin N: negated set membership -->
                <xsl:when test="starts-with($content,'&#x02209;')">
                    <xsl:value-of select="' notin '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02209;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--small element of -->
                <xsl:when test="starts-with($content,'&#x0220A;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/ni /owns R: contains -->
                <xsl:when test="starts-with($content,'&#x0220B;')">
                    <xsl:value-of select="' owns '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0220B;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--negated contains (just copy entity)-->
                <xsl:when test="starts-with($content,'&#x0220C;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--small contains -->
                <xsl:when test="starts-with($content,'&#x0220D;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/prod L: product operator -->
                <xsl:when test="starts-with($content,'&#x0220F;')">
                    <xsl:value-of select="' prod '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0220F;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/coprod L: coproduct operator -->
                <xsl:when test="starts-with($content,'&#x02210;')">
                    <xsl:value-of select="' coprod '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02210;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/sum L: summation operator -->
                <xsl:when test="starts-with($content,'&#x02211;')">
                    <xsl:value-of select="' sum '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02211;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--B: minus sign -->
                <xsl:when test="starts-with($content,'&#x02212;')">
                    <xsl:value-of select="'-'"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02212;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/mp B: minus-or-plus sign -->
                <xsl:when test="starts-with($content,'&#x02213;')">
                    <xsl:value-of select="' -+ '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02213;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/dotplus B: plus sign, dot above -->
                <xsl:when test="starts-with($content,'&#x02214;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>

                <!--<xsl:when test="starts-with($content,'&#x02215;')"><xsl:value-of select="substring($content,1,1)"/><xsl:call-template name="replaceEntities"><xsl:with-param name="content" select="substring($content, 2)"/></xsl:call-template></xsl:when>-->
                <!-- / division slash (just copy entity)-->
                
                <!--/setminus B: reverse solidus -->
                <xsl:when test="starts-with($content,'&#x02216;')">
                    <xsl:value-of select="' setminus '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02216;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--low asterisk -->
                <xsl:when test="starts-with($content,'&#x02217;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/circ B: composite function (small circle) -->
                <xsl:when test="starts-with($content,'&#x02218;')">
                    <xsl:value-of select="' circ '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02218;')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content,'&#x02219;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/surd radical -->
                <xsl:when test="starts-with($content,'&#x0221A;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/cube root -->
                <xsl:when test="starts-with($content,'&#x0221B;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/fourth root -->
                <xsl:when test="starts-with($content,'&#x0221C;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/propto R: is proportional to -->
                <xsl:when test="starts-with($content,'&#x0221D;')">
                    <xsl:value-of select="' prop '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0221D;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/infty infinity -->
                <xsl:when test="starts-with($content,'&#x0221E;')">
                    <xsl:value-of select="' infinity '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0221E;')"/>
                    </xsl:call-template>
                </xsl:when>

                <!--<xsl:when test="starts-with($content,'&#x0221F;')"><xsl:value-of select="substring($content,1,1)"/><xsl:call-template name="replaceEntities"><xsl:with-param name="content" select="substring($content, 2)"/></xsl:call-template></xsl:when>-->
                <!-- right (90 degree) angle (just copy entity)-->
                
                <!--/angle - angle -->
                <xsl:when test="starts-with($content,'&#x02220;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/measuredangle - angle-measured -->
                <xsl:when test="starts-with($content,'&#x02221;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/sphericalangle angle-spherical -->
                <xsl:when test="starts-with($content,'&#x02222;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/mid R: -->
                <xsl:when test="starts-with($content,'&#x02223;')">
                    <xsl:value-of select="' divides '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02223;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/nshortmid -->
                <xsl:when test="starts-with($content,'&#x02224;&#x0FE00;')">
                    <xsl:value-of select="' ndivides '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02224;&#x0FE00;')"
                        />
                    </xsl:call-template>
                </xsl:when>
                <!--/nmid -->
                <xsl:when test="starts-with($content,'&#x02224;')">
                    <xsl:value-of select="' ndivides '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02224;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/parallel R: parallel -->
                <xsl:when test="starts-with($content,'&#x02225;')">
                    <xsl:value-of select="' parallel '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02225;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/nshortparallel N: not short par -->
                <xsl:when test="starts-with($content,'&#x02226;&#x0FE00;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                    <xsl:value-of select="'\nshortparallel '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02226;&#x0FE00;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/nparallel N: not parallel -->
                <xsl:when test="starts-with($content,'&#x02226;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/wedge /land B: logical and -->
                <xsl:when test="starts-with($content,'&#x02227;')">
                    <xsl:value-of select="' and '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02227;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/vee /lor B: logical or -->
                <xsl:when test="starts-with($content,'&#x02228;')">
                    <xsl:value-of select="' or '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02228;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/cap B: intersection -->
                <xsl:when test="starts-with($content,'&#x02229;')">
                    <xsl:value-of select="' intersection '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02229;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/cup B: union or logical sum -->
                <xsl:when test="starts-with($content,'&#x0222A;')">
                    <xsl:value-of select="' union '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0222A;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/int L: integral operator -->
                <xsl:when test="starts-with($content,'&#x0222B;')">
                    <xsl:value-of select="' int '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0222B;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--double integral operator -->
                <xsl:when test="starts-with($content,'&#x0222C;')">
                    <xsl:value-of select="' iint '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0222C;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/iiint triple integral operator -->
                <xsl:when test="starts-with($content,'&#x0222D;')">
                    <xsl:value-of select="' iiint '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0222D;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/oiint L: contour integral operator -->
                <xsl:when test="starts-with($content,'&#x0222E;')">
                    <xsl:value-of select="' lint '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0222E;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/oiiint L: contour integral operator -->
                <xsl:when test="starts-with($content,'&#x0222F;')">
                    <xsl:value-of select="' llint '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0222F;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/oint L: contour integral operator -->
                <xsl:when test="starts-with($content,'&#x02230;')">
                    <xsl:value-of select="' lllint '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02230;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/ratio -->
                <xsl:when test="starts-with($content,':')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/ratio -->
                <!--&#x2231; à &#x223B;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x02231;&#x02232;&#x02233;&#x02234;&#x02235;&#x02236;&#x02237;&#x02238;&#x02239;&#x0223A;&#x0223B;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/sim R: similar -->
                <xsl:when test="starts-with($content,'&#x0223C;')">
                    <xsl:value-of select="' sim '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x0223C;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--&#x223D; à &#x223F;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x0223D;&#x0223E;&#x0223F;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>

                <!--&#x2240; à &#x2242;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x02240;&#x02241;&#x02242;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/simeq R: similar, equals -->
                <xsl:when test="starts-with($content,'&#x02243;')">
                    <xsl:value-of select="' simeq '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02243;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--&#x2244; à &#x2247;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x02244;&#x02245;&#x02246;&#x02247;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/approx R: approximate -->
                <xsl:when test="starts-with($content,'&#x02248;')">
                    <xsl:value-of select="' approx '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02248;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--&#x2248; à &#x224F;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x02248;&#x02249;&#x0224A;&#x0224B;&#x0224C;&#x0224D;&#x0224E;&#x0224F;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>

                <!--&#x2250; à &#x225F;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x02250;&#x02251;&#x02252;&#x02253;&#x02254;&#x02255;&#x02256;&#x02257;&#x02258;&#x02259;&#x0225A;&#x0225B;&#x0225C;&#x0225D;&#x0225E;&#x0225F;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                
                <!--/ne /neq R: not equal -->
                <xsl:when test="starts-with($content,'&#x02260;')">
                    <xsl:value-of select="' &lt;&gt; '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02260;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/equiv R: identical with -->
                <xsl:when test="starts-with($content,'&#x02261;')">
                    <xsl:value-of select="' equiv '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02261;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/nequiv N: not identical with  (just copy entity)-->
                <xsl:when test="starts-with($content,'&#x02262;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!-- strctly equivalent to -->
                <xsl:when test="starts-with($content,'&#x02263;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/leq /le R: less-than-or-equal -->
                <xsl:when test="starts-with($content,'&#x02264;')">
                    <xsl:value-of select="' &lt;= '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02264;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/geq /ge R: greater-than-or-equal -->
                <xsl:when test="starts-with($content,'&#x02265;')">
                    <xsl:value-of select="' &gt;= '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02265;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--&#x2266; à &#x226F;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x02266;&#x02267;&#x02268;&#x02269;&#x0226A;&#x0226B;&#x0226C;&#x0226D;&#x0226E;&#x0226F;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>

                <!--&#x2270; à &#x227F;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x02270;&#x02271;&#x02272;&#x02273;&#x02274;&#x02275;&#x02276;&#x02277;&#x02278;&#x02279;&#x0227A;&#x0227B;&#x0227C;&#x0227D;&#x0227E;&#x0227F;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content,'&#x02282;')">
                    <xsl:value-of select="' subset '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02282;')"/>
                    </xsl:call-template>
                </xsl:when>
                
                <!--/subset R: subset or is implied by -->
                <xsl:when test="starts-with($content,'&#x02282;')">
                    <xsl:value-of select="' subset '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02282;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/supset R: superset or implies -->
                <xsl:when test="starts-with($content,'&#x02283;')">
                    <xsl:value-of select="' supset '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02283;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--not subset -->
                <xsl:when test="starts-with($content,'&#x02284;')">
                    <xsl:value-of select="' nsubset '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02284;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--not superset -->
                <xsl:when test="starts-with($content,'&#x02285;')">
                    <xsl:value-of select="' nsupset '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02285;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/subseteq R: subset, equals -->
                <xsl:when test="starts-with($content,'&#x02286;')">
                    <xsl:value-of select="' subseteq '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02286;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/supseteq R: superset, equals -->
                <xsl:when test="starts-with($content,'&#x02287;')">
                    <xsl:value-of select="' supseteq '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02287;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/supseteq R: superset, equals -->
                <xsl:when test="starts-with($content,'&#x02288;')">
                    <xsl:value-of select="' nsubseteq '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x02288;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--&#x2289; à &#x228F;-->
                <xsl:when test="starts-with(translate($content,'&#x02289;&#x0228A;&#x0228B;&#x0228C;&#x0228D;&#x0228E;&#x0228F;','&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),'&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when> 

                <!--&#x2290; à &#x229F;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x02290;&#x02291;&#x02292;&#x02293;&#x02294;&#x02295;&#x02296;&#x02297;&#x02298;&#x02299;&#x0229A;&#x0229B;&#x0229C;&#x0229D;&#x0229E;&#x0229F;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                
                <!--&#x22A0; à &#x22A4;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x022A0;&#x022A1;&#x022A2;&#x022A3;&#x022A4;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/perp R: perpendicular -->
                <xsl:when test="starts-with($content,'&#x022A5;')">
                    <xsl:value-of select="' ortho '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x022A5;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--&#x22A6; à &#x22AF;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x022A6;&#x022A7;&#x022A8;&#x022A9;&#x022AA;&#x022AB;&#x022AC;&#x022AD;&#x022AE;&#x022AF;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>

                <!--&#x22B0; à &#x22BF;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x022B0;&#x022B1;&#x022B2;&#x022B3;&#x022B4;&#x022B5;&#x022B6;&#x022B7;&#x022B8;&#x022B9;&#x022BA;&#x022BB;&#x022BC;&#x022BD;&#x022BE;&#x022BF;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                
                <!--/bigwedge L: logical and operator -->
                <xsl:when test="starts-with($content,'&#x022C0;')">
                    <xsl:value-of select="' and '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x022C0;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/bigvee L: logical and operator -->
                <xsl:when test="starts-with($content,'&#x022C1;')">
                    <xsl:value-of select="' or '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x022C1;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/bigcap L: intersection operator -->
                <xsl:when test="starts-with($content,'&#x022C2;')">
                    <xsl:value-of select="' intersection '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x022C2;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/bigcup L: union operator -->
                <xsl:when test="starts-with($content,'&#x022C3;')">
                    <xsl:value-of select="' union '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x022C3;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/diamond B: open diamond -->
                <xsl:when test="starts-with($content,'&#x022C4;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/cdot B: small middle dot -->
                <xsl:when test="starts-with($content,'&#x022C5;')">
                    <xsl:value-of select="' cdot '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x022C5;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--&#x22C6; à &#x22CF;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x022C6;&#x022C7;&#x022C8;&#x022C9;&#x022CA;&#x022CB;&#x022CC;&#x022CD;&#x022CE;&#x022CF;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>

                <!--&#x22D0; à &#x22DF;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x022D0;&#x022D1;&#x022D2;&#x022D3;&#x022D4;&#x022D5;&#x022D6;&#x022D7;&#x022D8;&#x022D9;&#x022DA;&#x022DB;&#x022DC;&#x022DD;&#x022DE;&#x022DF;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                
                <!--&#x22E0; à &#x22EF;-->
                <xsl:when test="starts-with(translate($content,
                    '&#x022E0;&#x022E1;&#x022E2;&#x022E3;&#x022E4;&#x022E5;&#x022E6;&#x022E7;&#x022E8;&#x022E9;&#x022EA;&#x022EB;&#x022EC;&#x022ED;',
                    '&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),
                    '&#x0CCCC;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/cdots, three dots, vertical -->
                <xsl:when test="starts-with($content,'&#x022EE;')">
                    <xsl:value-of select="' dotsvert '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x022EE;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/cdots, three dots, centered -->
                <xsl:when test="starts-with($content,'&#x022EF;')">
                    <xsl:value-of select="' dotsaxis '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x022EF;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/ddots, three dots, ascending -->
                <xsl:when test="starts-with($content,'&#x022F0;')">
                    <xsl:value-of select="' dotsup '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x022F0;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/ddots, three dots, descending -->
                <xsl:when test="starts-with($content,'&#x022F1;')">
                    <xsl:value-of select="' dotsdown '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x022F1;')"/>
                    </xsl:call-template>
                </xsl:when>
                
                <!-- ====================================================================== -->
                <!--/square, square -->
                <xsl:when test="starts-with($content,'&#x025A1;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/blacksquare, square, filled  -->
                <xsl:when test="starts-with($content,'&#x025AA;')">
                    <xsl:call-template name="insertEntity">
                        <xsl:with-param name="content" select="$content"/>
                    </xsl:call-template>
                </xsl:when>



                <xsl:when test="starts-with($content,'|')">
                    <xsl:value-of select="' lline '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '|')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content,'(')">
                    <xsl:value-of select="' ('"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '(')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content,')')">
                    <xsl:value-of select="' )'"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, ')')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content,'[')">
                    <xsl:value-of select="' ['"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '[')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content,']')">
                    <xsl:value-of select="' ]'"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, ']')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content,'{')">
                    <xsl:value-of select="' lbrace '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '{')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content,'}')">
                    <xsl:value-of select="' rbrace '"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '}')"/>
                    </xsl:call-template>
                </xsl:when>
                
                
                <!--/"A" DoubleStruck, Fractur, Script -->
                <xsl:when test="starts-with($content, '&#x1D538;')">
                    <xsl:text>font sans bold {"A"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D538;')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content, '&#x1D56C;')">
                    <xsl:text>font sans bold {"A"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D56C;')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content, '&#x1D49C;')">
                    <xsl:text>font sans bold {"A"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D49C;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"B" DoubleStruck, Fractur, Script -->
                <xsl:when test="starts-with($content, '&#x1D539;')">
                    <xsl:text>font sans bold {"B"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D539;')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content, '&#x1D56D;')">
                    <xsl:text>font sans bold {"B"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D56D;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"C" Fractur, Script -->
                <xsl:when test="starts-with($content, '&#x1D56E;')">
                    <xsl:text>font sans bold {"C"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D56E;')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content, '&#x1D49E;')">
                    <xsl:text>font sans bold {"C"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D49E;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"D" DoubleStruck, Fractur, Script -->
                <xsl:when test="starts-with($content, '&#x1D56F;')">
                    <xsl:text>font sans bold {"D"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D56F;')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content, '&#x1D49F;')">
                    <xsl:text>font sans bold {"D"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D49F;')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content, '&#x1D53B;')">
                    <xsl:text>font sans bold {"D"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D53B;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"E" DoubleStruck, Fractur, Script -->
                <xsl:when test="starts-with($content, '&#x1D53C;')">
                    <xsl:text>font sans bold {"E"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D53C;')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:when test="starts-with($content, '&#x1D570;')">
                    <xsl:text>font sans bold {"E"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D570;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"F" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D53D;')">
                    <xsl:text>font sans bold {"F"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D53D;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D571;')">
                    <xsl:text>font sans bold {"F"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D571;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"G" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D53E;')">
                    <xsl:text>font sans bold {"G"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D53E;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D572;')">
                    <xsl:text>font sans bold {"G"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D572;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4A2;')">
                    <xsl:text>font sans bold {"G"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4A2;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"H" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D572;')">
                    <xsl:text>font sans bold {"H"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D572;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"I" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D540;')">
                    <xsl:text>font sans bold {"I"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D540;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D574;')">
                    <xsl:text>font sans bold {"I"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D574;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"J" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D541;')">
                    <xsl:text>font sans bold {"J"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D541;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D575;')">
                    <xsl:text>font sans bold {"J"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D575;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4A5;')">
                    <xsl:text>font sans bold {"J"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4A5;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"K" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D542;')">
                    <xsl:text>font sans bold {"K"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D542;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D576;')">
                    <xsl:text>font sans bold {"K"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D576;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4A6;')">
                    <xsl:text>font sans bold {"K"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4A6;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"L" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D543;')">
                    <xsl:text>font sans bold {"L"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D543;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D577;')">
                    <xsl:text>font sans bold {"L"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D577;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"M" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D544;')">
                    <xsl:text>font sans bold {"M"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D544;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D578;')">
                    <xsl:text>font sans bold {"M"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D578;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"N" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D579;')">
                    <xsl:text>font sans bold {"N"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D579;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4A9;')">
                    <xsl:text>font sans bold {"N"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4A9;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"O" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D546;')">
                    <xsl:text>font sans bold {"O"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D546;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D57A;')">
                    <xsl:text>font sans bold {"O"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D57A;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4AA;')">
                    <xsl:text>font sans bold {"O"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4AA;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"P" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D57B;')">
                    <xsl:text>font sans bold {"P"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D57B;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4AB;')">
                    <xsl:text>font sans bold {"P"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4AB;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"Q" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D57C;')">
                    <xsl:text>font sans bold {"Q"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D57C;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4AC;')">
                    <xsl:text>font sans bold {"Q"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4AC;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"R" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D57D;')">
                    <xsl:text>font sans bold {"R"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D57D;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"S" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D54A;')">
                    <xsl:text>font sans bold {"S"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D54A;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D57E;')">
                    <xsl:text>font sans bold {"S"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D57E;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4AE;')">
                    <xsl:text>font sans bold {"S"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4AE;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"T" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D54B;')">
                    <xsl:text>font sans bold {"T"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D54B;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D57F;')">
                    <xsl:text>font sans bold {"T"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D57F;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4AF;')">
                    <xsl:text>font sans bold {"T"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4AF;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"U" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D54C;')">
                    <xsl:text>font sans bold {"U"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D54C;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D54C;')">
                    <xsl:text>font sans bold {"U"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D54C;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4B0;')">
                    <xsl:text>font sans bold {"U"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4B0;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"V" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D54D;')">
                    <xsl:text>font sans bold {"V"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D54D;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D581;')">
                    <xsl:text>font sans bold {"V"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D581;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4B1;')">
                    <xsl:text>font sans bold {"V"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4B1;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"W" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D54E;')">
                    <xsl:text>font sans bold {"W"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D54E;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D582;')">
                    <xsl:text>font sans bold {"W"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D582;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4B2;')">
                    <xsl:text>font sans bold {"W"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4B2;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"X" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D54F;')">
                    <xsl:text>font sans bold {"X"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D54F;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D583;')">
                    <xsl:text>font sans bold {"X"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D583;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4B3;')">
                    <xsl:text>font sans bold {"X"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4B3;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"Y" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D550;')">
                    <xsl:text>font sans bold {"Y"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D550;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D584;')">
                    <xsl:text>font sans bold {"Y"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D584;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4B4;')">
                    <xsl:text>font sans bold {"Y"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4B4;')"/>
                    </xsl:call-template>
                </xsl:when>
                <!--/"Z" DoubleStruck, Fractur, Script -->
                 <xsl:when test="starts-with($content, '&#x1D585;')">
                    <xsl:text>font sans bold {"Z"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D585;')"/>
                    </xsl:call-template>
                </xsl:when>
                 <xsl:when test="starts-with($content, '&#x1D4B5;')">
                    <xsl:text>font sans bold {"Z"} </xsl:text>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring-after($content, '&#x1D4B5;')"/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="substring($content,1,1)"/>
                    <xsl:call-template name="replaceEntities">
                        <xsl:with-param name="content" select="substring($content, 2)"/>
                    </xsl:call-template>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>

</xsl:stylesheet>
