<?xml version='1.0' encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:m="http://www.w3.org/1998/Math/MathML"
	version="1.0">
	
	<!-- ====================================================================== -->
	<!-- $id: tokens.xsl, 2002/22/11 Exp $
    	 This file is part of the XSLT MathML Library distribution.
		 See ./README or http://www.raleigh.ru/MathML/mmltex for
		 copyright and other information                                        -->
	<!-- ====================================================================== -->
<!-- FRK -->
	
	<xsl:template match="m:mi|m:mn|m:mo|m:mtext|m:ms">
		<xsl:call-template name="CommonTokenAtr"/>
	</xsl:template>

	<xsl:template name="mi">
		<xsl:choose>
			<xsl:when test="string-length(normalize-space(.))>1 and not(@mathvariant)">
				<xsl:text> </xsl:text>
				<xsl:apply-templates/>
				<xsl:text> </xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="mn">
		<xsl:apply-templates/>
	</xsl:template>

	
	<xsl:template name="getOpenCloseString">
		<xsl:param name="node"/>
		<!-- Création d'une chaine de caractère stockant les positions gauche/droite de chaque parenthèse/crochet...
			L=Left, R=Right,N=ne pas prendre
		-->
		<xsl:variable name="pos">
			<xsl:for-each select="$node/child::m:mo[starts-with(translate(./text(),'{([|)]}','((((((('),'(')]">
				<xsl:choose>
					<!-- On considère que "(" et "{" sont systématiquement à gauche -->
					<xsl:when test="starts-with(translate(child::text(),'({','(('),'(')">
						<xsl:text>L</xsl:text>
					</xsl:when>
					<!-- On considère que ")" et "}" sont systématiquement à droite -->
					<xsl:when test="starts-with(translate(child::text(),')}','(('),'(')">
						<xsl:text>R</xsl:text>
					</xsl:when>
					<!-- On considère que le premier parenthésage est systématiquement à gauche -->
					<xsl:when test="count(preceding-sibling::m:mo[contains(translate(text(),'({[|)]}','((((((('),'(')])=0">
						<xsl:text>L</xsl:text>
					</xsl:when>
					<!-- On considère que le dernier parenthésage est systématiquement à droite -->
					<xsl:when test="count(following-sibling::m:mo[contains(translate(text(),'({[|)]}','((((((('),'(')])=0">
						<xsl:choose>
							<!-- Si rencontré 2 "|" consé&cutifs alors il s'agit de la norme d'un vecteur et non d'une valeur absolue -->
							<xsl:when test="starts-with(child::text(),'|') and starts-with(preceding-sibling::*[1]/child::text(),'|')">
								<xsl:text>N</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>R</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<!-- Cas des | et double || on considère qu'il vont par paires-->
					<xsl:when test="starts-with(text(),'|')">
						<xsl:choose>
							<!-- Si rencontré 2 "|" consé&cutifs alors il s'agit de la norme d'un vecteur et non d'une valeur absolue 
								on mets de coté le second "|"-->
							<xsl:when test="starts-with(child::text(),'|') and starts-with(preceding-sibling::*[1]/child::text(),'|')">
								<xsl:text>N</xsl:text>
							</xsl:when>
							<!-- si le nombre précédent de "|" ou de double '||' est pair alors mettre à gauche sinon à droite-->
							<xsl:when test="((count(preceding-sibling::m:mo[contains(text(),'|')]) - count(preceding-sibling::m:mo[contains(text(),'|') and preceding-sibling::*[1][contains(text(),'|')]])) mod 2) = 0">
								<xsl:text>L</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>R</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<!-- cas des [] on considère qu'ils vont pas paires -->
					<xsl:when test="starts-with(translate(text(),'[]','(('),'(')">
						<xsl:choose>
							<xsl:when test="(count (preceding-sibling::m:mo[contains(translate(text(),'[]','(('),'(')]) mod 2) = 0">
								<xsl:text>L</xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:text>R</xsl:text>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<!-- cas non traité, normalement impossible -->
						<xsl:text>Z</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:variable>
		<xsl:value-of select="$pos"/>
	</xsl:template>
	
	<xsl:template name="mo">
		<xsl:choose>
			<!-- Traitement spécifiques des opérateurs binaires -->
			<!-- Cas repectifs des opérateurs  '=', times, appartient, n'appartient pas, contient, différent de, identique,-,+,*,/,<,>,<=,>=, approx, divise, ne divise pas, parallel, sim equal, similar, proportionnel, moins, -+, ., et logique, ou logique, intersection, union, différence, inclu, inclu ou egal, contient, pas inclu, ne contient pas, contient ou est egal, non inclu ou egal, non contient ou egal-->
			<xsl:when
				test="starts-with(translate(child::text(),'=&#x00D7;&#x02208;&#x02209;&#x0220B;&#x02260;&#x02261;-+*/&lt;&gt;&#x02264;&#x02265;&#x02248;&#x02223;&#x02224;&#x02225;&#x02243;&#x0223C;&#x0221D;&#x02212;&#x02213;&#x022C5;&#x02227;&#x02228;&#x02229;&#x0222A;&#x02216;&#x02282;&#x02286;&#x02283;&#x02284;&#x02285;&#x02287;&#x02288;&#x02289;&#x022C0;&#x022C1;&#x022C2;&#x022C3;',
				'&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),'&#x0CCCC;')">
				<xsl:choose>
					<!-- Il faut protéger les opérateurs binaires par {{}operateur{}} pour qu'il i ait quelquechose avant et après qui ne soit pas lui même un opérateur binaire  (pb openoffice) -->
					<xsl:when test="count(preceding-sibling::*)=0 or count(following-sibling::*)=0 or 
						starts-with(translate(following-sibling::*[1]/text(),')]}|=&#x00D7;&#x02208;&#x02209;&#x0220B;&#x02260;&#x02261;-+*/&lt;&gt;&#x02264;&#x02265;&#x02248;&#x02223;&#x02224;&#x02225;&#x02243;&#x0223C;&#x0221D;&#x02212;&#x02213;&#x022C5;&#x02227;&#x02228;&#x02229;&#x0222A;&#x02216;&#x02282;&#x02286;&#x02283;&#x02284;&#x02285;&#x02287;&#x02288;&#x02289;&#x022C0;&#x022C1;&#x022C2;&#x022C3;',
						'&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),'&#x0CCCC;')" >
						<xsl:text>{{}</xsl:text>
						<xsl:apply-templates/>
						<xsl:text>{}}</xsl:text>
					</xsl:when>
					<!-- dans les autre cas tout va bien -->
					<xsl:otherwise>
						<xsl:apply-templates/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<!-- Traitement des parenthésages. openoffice oblige si on veu disposer de parenthèses, crochet,accolades 
				redimensionnable en fonction du contenu d'avoir une ouverture et fermeture du parenthésage. 
				Impossible de fermer sans avoir ouver avant ni d'ouvrir sans fermer après. L'écriture est non ambigue sous openoffice
				par contre elle peut l'être en mathml.
				Le traitement ne pourra donc pas fonctionner à 100% 
			-->
			<xsl:when test="starts-with(translate(child::text(),'{([|)]}','((((((('),'(')">
				<!-- Création d'une chaine de caractère stockant les positions gauche/droite de chaque parenthèse/crochet...
					L=Left, R=Right,N=ne pas prendre
				-->
				<xsl:variable name="pos">
					<xsl:call-template name="getOpenCloseString">
						<xsl:with-param name="node" select="parent::*"></xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<!-- Traitement de la bzalise mo à proprement parlé -->
				<!-- si on est sur le premier mo contenant du parenthésage et que la chaine $pos commence par des 'R' 
					alors il faut protéger la chaine odf par des 'left none' -->
				<xsl:if test="count(preceding-sibling::m:mo[starts-with(translate(text(),'{([|)]}','((((((('),'(')])=0">
					<xsl:call-template name="addleft">
						<xsl:with-param name="str">
							<xsl:value-of select="$pos"/>
						</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				<xsl:choose>
					<!-- si $pos[i] = 'R' alors 'right' -->
					<xsl:when test="substring($pos,count(preceding-sibling::m:mo[starts-with(translate(text(),'{([|)]}','((((((('),'(')])+1,1)='R'">
						<xsl:text> right </xsl:text>
						<xsl:choose>
							<xsl:when test="starts-with(child::text(),'|') and starts-with(following-sibling::*[1]/child::text(),'|')">
								<xsl:text> rdline </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<!-- si $pos[i] = 'l' alors 'left' -->
					<xsl:when test="substring($pos,count(preceding-sibling::m:mo[starts-with(translate(text(),'{([|)]}','((((((('),'(')])+1,1)='L'">
						<xsl:text> left </xsl:text>
						<xsl:choose>
							<xsl:when test="starts-with(child::text(),'|') and starts-with(following-sibling::*[1]/child::text(),'|')">
								<xsl:text> ldline </xsl:text>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<!-- sinon ne rien faire celà élimine les deuxième | dans une double || -->
					<xsl:otherwise/>
				</xsl:choose>
				<!-- si on est sur le dernier mo contenant du parenthésage et qu'il y plus de left que de right alors fermer par des 'right none'-->
				<!-- ATTENTION 
					Ce traitement ne peut se faire ici. Il doit être fait dans le noeud parent (mrow,mstyle,mtd) -->
			</xsl:when>
			<!-- Trantement des sommes, limites... pour ajouter {} si c'est le dernier noeud -->
			<xsl:when test="count(following-sibling::*)=0 and (text()='lim' or contains(translate(text(),
				'&#x0220F;&#x02210;&#x0222B;&#x0222C;&#x0222D;&#x0222E;&#x0222F;&#x02230;&#x02211;'
				,'&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;&#x0CCCC;'),'&#x0CCCC;'))">
				<xsl:apply-templates/>
				<!-- Ne traiter que dans les cas où on n'est pas sous un munder, msub...-->
				<xsl:if test="not (count(parent::*/preceding-sibling::*)=0 and (ancestor::m:munder or ancestor::m:mover or 
					ancestor::m:munderover or ancestor::m:msub or ancestor::m:msup or ancestor::m:subsup))">
					<xsl:text>{}</xsl:text>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="addleft">
		<xsl:param name="str"/>
		<xsl:if test="starts-with($str,'R')">
			<xsl:text> left none </xsl:text>
			<xsl:call-template name="addleft">
				<xsl:with-param name="str" select="substring-after($str,'R')"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>
	
	<xsl:template name="addright">
		<xsl:param name="str"/>
		<xsl:param name="nb"/>
		<xsl:choose>
			<xsl:when test="string-length($str)=0">
				<xsl:if test="$nb > 0">
					<xsl:text> right none </xsl:text>
					<xsl:call-template name="addright">
						<xsl:with-param name="str">
							<xsl:value-of select="''"/>
						</xsl:with-param>
						<xsl:with-param name="nb">
							<xsl:value-of select="$nb -1"/>
						</xsl:with-param>							
					</xsl:call-template>
				</xsl:if>
			</xsl:when>
			<xsl:otherwise>
				<xsl:choose>
					<!-- si "L" on incrémente le compteur et réduit la string -->
					<xsl:when test="starts-with($str,'L')">
						<xsl:call-template name="addright">
							<xsl:with-param name="str">
								<xsl:value-of select="substring($str,2)"/>
							</xsl:with-param>
							<xsl:with-param name="nb">
								<xsl:value-of select="$nb +1"/>
							</xsl:with-param>							
						</xsl:call-template>
					</xsl:when>
					<!-- si "R" on décémente le conmteur et réduit la string -->
					<xsl:when test="starts-with($str,'R')">
						<xsl:call-template name="addright">
							<xsl:with-param name="str">
								<xsl:value-of select="substring($str,2)"/>
							</xsl:with-param>
							<xsl:with-param name="nb">
								<xsl:value-of select="$nb -1"/>
							</xsl:with-param>							
						</xsl:call-template>
					</xsl:when>
					<!-- sinon on réduit la string -->
					<xsl:otherwise>
						<xsl:call-template name="addright">
							<xsl:with-param name="str">
								<xsl:value-of select="substring($str,2)"/>
							</xsl:with-param>
							<xsl:with-param name="nb">
								<xsl:value-of select="$nb"/>
							</xsl:with-param>							
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="mtext">
		<xsl:text>"</xsl:text>
		<xsl:apply-templates/>
		<xsl:text>"</xsl:text>
	</xsl:template>
	
	<xsl:template match="m:mspace">
		<xsl:text>~</xsl:text>
	</xsl:template>

	<xsl:template name="ms">
		<xsl:text>"</xsl:text>
		<xsl:choose>
			<xsl:when test="@lquote">
				<xsl:value-of select="@lquote"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>''</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:apply-templates/>
		<xsl:choose>
			<xsl:when test="@rquote">
				<xsl:value-of select="@rquote"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>''</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:text>"</xsl:text>
	</xsl:template>

	<xsl:template name="CommonTokenAtr">
		<xsl:if test="@color or @mathcolor">
			<!-- Note: @color is deprecated in MathML 2.0 -->
			<xsl:call-template name="color">
				<xsl:with-param name="color" select="@color|@mathcolor"/>
			</xsl:call-template>
			<xsl:text>{</xsl:text>
		</xsl:if>
		<xsl:if test="@mathvariant">
			<xsl:choose>
				<xsl:when test="@mathvariant='normal'">
					<xsl:text>font serif {</xsl:text>
				</xsl:when>
				<xsl:when test="@mathvariant='serif'">
					<xsl:text>font serif {</xsl:text>
				</xsl:when>
				<xsl:when test="@mathvariant='bold'">
					<xsl:text> bold{</xsl:text>
				</xsl:when>
				<xsl:when test="@mathvariant='italic'">
					<xsl:text> ital{</xsl:text>
				</xsl:when>
				<xsl:when test="@mathvariant='sans-serif'">
					<xsl:text> font sans {</xsl:text>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>{</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:call-template name="selectTemplate"/>
		<xsl:if test="@mathvariant">
			<xsl:text>}</xsl:text>
		</xsl:if>
		<xsl:if test="@color or @mathcolor">
			<xsl:text>}</xsl:text>
		</xsl:if>
	</xsl:template>

	<xsl:template name="selectTemplate">
		<xsl:choose>
			<xsl:when test="local-name(.)='mi'">
				<xsl:call-template name="mi"/>
			</xsl:when>
			<xsl:when test="local-name(.)='mn'">
				<xsl:call-template name="mn"/>
			</xsl:when>
			<xsl:when test="local-name(.)='mo'">
				<xsl:call-template name="mo"/>
			</xsl:when>
			<xsl:when test="local-name(.)='mtext'">
				<xsl:call-template name="mtext"/>
			</xsl:when>
			<xsl:when test="local-name(.)='ms'">
				<xsl:call-template name="ms"/>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template name="color">
		<!-- NB: Variables colora and valueColor{n} only for Sablotron -->
		<xsl:param name="color"/>
		<xsl:variable name="colora" select="translate($color,'ABCDEFGHIJKLMNOPQRSTUVWXYZ','abcdefghijklmnopqrstuvwxyz')"/>
		<xsl:choose>
			<xsl:when test="$colora='cyan'">
				<xsl:text> color cyan </xsl:text>
			</xsl:when>
			<xsl:when test="$colora='black'">
				<xsl:text> color black </xsl:text>
			</xsl:when>
			<xsl:when test="$colora='blue'">
				<xsl:text> color blue </xsl:text>
			</xsl:when>
			<xsl:when test="$colora='green'">
				<xsl:text> color green </xsl:text>
			</xsl:when>
			<xsl:when test="$colora='red'">
				<xsl:text> color red </xsl:text>
			</xsl:when>
			<xsl:when test="$colora='white'">
				<xsl:text> color white </xsl:text>
			</xsl:when>
			<xsl:when test="$colora='yellow'">
				<xsl:text> color yellow </xsl:text>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="m:*/text()">
		<xsl:call-template name="replaceEntities">
			<xsl:with-param name="content" select="normalize-space()"/>
		</xsl:call-template>
	</xsl:template>
<!-- /FRK -->
</xsl:stylesheet>
